#!/usr/bin/perl

use strict;
use Test::More tests => 20;

# 1
BEGIN { use_ok('FDN::Sql::Plutar::Basic'); }

# 2
BEGIN { use_ok('FDN::Common::Config'); }
BEGIN { $FDN::Common::Config::CONFIG_ROOT='./t/'; }

# 3
my $res;
my $tid;
my $args = {};
$res = plutar_select_db('test');
ok ( $res, 'plutar_select_db');

# There already have been tasks in the test of FDN-libs. We cannot guess the
# first task id. We have to remember it.
# Task 1 will succeed
$args->{'return'} = 'success';
my $tid1 = new_plutar('test','now');
set_plutar_properties($tid1,$args);

# Task 2 will fail
# 4
$args->{'return'} = 'fail';
my $tid2 = new_plutar('test','now');
is ( $tid2, $tid1+1, 'new_plutar' );
set_plutar_properties($tid2,$args);

# Task 3 will retry then succeed
# 5
$args->{'return'} = 'other';
my $tid3 = new_plutar('test','now');
is ( $tid3, $tid2+1, 'new_plutar');
set_plutar_properties($tid3,$args);

# Task 4 will fail with no args.
# 6
my $tid4 = new_plutar('test1','now');
is ( $tid4, $tid3+1, 'new_plutar');

# Task 5 will retry 12 times and then fail
# 7
my $tid5 = new_plutar('test2','now');
is ( $tid5, $tid4+1, 'new_plutar');

# task 6 will succeed immediately.
# 8
my $tid6 = new_plutar('test3','now');
is ( $tid6, $tid5+1, 'new_plutar');

`perl -I . plutar.pl -C ./t/ -c plutar.cfg -v`;

# 9-10
my $t1 = plutar_par_id($tid1);
is ( $t1->{'PLUTAR_ETAT'}, 'done', 'plutar');
is ( $t1->{'PLUTAR_NBRUN'}, 1, 'plutar');

# 11-12
my $t2 = plutar_par_id($tid2);
is ( $t2->{'PLUTAR_ETAT'}, 'failed', 'plutar');
is ( $t2->{'PLUTAR_NBRUN'}, 1, 'plutar');

# 13-14
my $t3 = plutar_par_id($tid3);
is ( $t3->{'PLUTAR_ETAT'}, 'done', 'plutar');
is ( $t3->{'PLUTAR_NBRUN'}, 2, 'plutar');

# 15-16
my $t4 = plutar_par_id($tid4);
is ( $t4->{'PLUTAR_ETAT'}, 'failed', 'plutar');
is ( $t4->{'PLUTAR_NBRUN'}, 1, 'plutar');

# 17-18
my $t5 = plutar_par_id($tid5);
is ( $t5->{'PLUTAR_ETAT'}, 'failed', 'plutar');
is ( $t5->{'PLUTAR_NBRUN'}, 12, 'plutar');

# 19-20
my $t6 = plutar_par_id($tid6);
is ( $t6->{'PLUTAR_ETAT'}, 'done', 'plutar');
is ( $t6->{'PLUTAR_NBRUN'}, 1, 'plutar');

plutar_close_db();

